from colorama import Fore
from datetime import datetime
from time     import time
from re       import sub

from .console import Settings


class Console: # for older versions support or if ppl dont wanna use print() lol
    def init(
        debug: bool = True,
        showTimestamp: bool = True,
        colMain = Fore.LIGHTBLUE_EX,
        colSeco = Fore.LIGHTBLACK_EX,
        madeBy = "vast#1337"
    ):
        Settings.initialized = True
        Settings.debug = debug
        Settings.timestamp = showTimestamp
        Settings.c_MAIN = colMain
        Settings.c_SECO = colSeco


    @staticmethod
    def printf(content: str, mainCol=None, showTimestamp=None):
        if showTimestamp is None: showTimestamp = Settings.timestamp
        if mainCol is None: mainCol = Settings.c_MAIN
        if type(content) != str: return print(content)
        if (
            ("(!)" in content)
            or ("(-)" in content)
            or ("(~)" in content) 
            or ("debug" in content.lower())
            ) and (Settings.debug == False): return
        
        timestamp = f'{Settings.c_SECO}{datetime.fromtimestamp(time()).strftime("%H:%M:%S")}{Fore.RESET} ' if (showTimestamp) else ''
        
        content   = sub(r'\[(.*?)]', rf'{Settings.c_SECO}[{mainCol}\1{Settings.c_SECO}]{Fore.RESET}', content)
        content   = content\
            .replace("|", f"{Settings.c_SECO}|{mainCol}")\
            .replace("->", f"{Settings.c_SECO}->{mainCol}")\
            .replace("(+)", f"{Settings.c_SECO}({Fore.GREEN}+{Settings.c_SECO}){mainCol}")\
            .replace("($)", f"{Settings.c_SECO}({Fore.GREEN}${Settings.c_SECO}){mainCol}")\
            .replace("(-)", f"{Settings.c_SECO}({Fore.RED}-{Settings.c_SECO}){mainCol}")\
            .replace("(!)", f"{Settings.c_SECO}({Fore.RED}!{Settings.c_SECO}){mainCol}")\
            .replace("(~)", f"{Settings.c_SECO}({Fore.YELLOW}~{Settings.c_SECO}){mainCol}")\
            .replace("(#)", f"{Settings.c_SECO}({Fore.BLUE}#{Settings.c_SECO}){mainCol}")\
            .replace("(*)", f"{Settings.c_SECO}({Fore.CYAN}*{Settings.c_SECO}){mainCol}")
        
            # .replace("(", f"{Settings.c_SECO}({Fore.RESET}").replace(")", f"{Settings.c_SECO}){Fore.RESET}")
            # .replace("[", f"{Settings.c_SECO}[{mainCol}")\
            
        return print(timestamp + content, end=f"{Fore.RESET}\n")
        
        
    @staticmethod
    def inputf(content: str):
        if "(?)" not in content: x = f"{Settings.c_SECO}({Settings.c_MAIN}?{Settings.c_SECO}){Fore.RESET} "
        else: x = ""
        content = x + content\
            .replace("(", f"{Settings.c_SECO}({Settings.c_MAIN}").replace(")", f"{Settings.c_SECO}){Settings.c_MAIN}")\
            .replace(">", f"{Settings.c_SECO}>{Fore.RESET}")
        return input(content)



from colorama import Fore as C

RESET           = C.RESET

BLACK           = C.BLACK
RED             = C.RED
GREEN           = C.GREEN
YELLOW          = C.YELLOW
BLUE            = C.BLUE
MAGENTA         = C.MAGENTA
CYAN            = C.CYAN
WHITE           = C.WHITE

LIGHTBLACK      = C.LIGHTBLACK_EX
LIGHTRED        = C.LIGHTRED_EX
LIGHTGREEN      = C.LIGHTGREEN_EX
LIGHTYELLOW     = C.LIGHTYELLOW_EX
LIGHTBLUE       = C.LIGHTBLUE_EX
LIGHTMAGENTA    = C.LIGHTMAGENTA_EX
LIGHTCYAN       = C.LIGHTCYAN_EX
LIGHTWHITE      = C.LIGHTWHITE_EX


from datetime import datetime
from time     import time
from colorama import Fore, init
from .colors  import *

from .console import Settings


class log:
    def __init__(self) -> None:
        init(autoreset=True)

    @staticmethod
    def _get_timestamp():
        if Settings.timestamp:
            timestamp = f"[{Settings.c_SECO}{datetime.fromtimestamp(time()).strftime('%H:%M:%S')}{Fore.RESET}]"
            if not Settings.wrapTime:
                timestamp = timestamp[1:-1]
        else:
            timestamp = ""
        return timestamp
    
    @staticmethod
    def success(text: str, sep: str = " "):
        timestamp = log._get_timestamp()
        print(f"{timestamp} {Fore.GREEN}YES {Fore.LIGHTBLACK_EX}{sep}{Fore.RESET}{text}")
        
    @staticmethod
    def info(text: str, sep: str = " "):
        timestamp = log._get_timestamp()
        print(f"{timestamp} {Fore.LIGHTMAGENTA_EX}INF {Fore.LIGHTBLACK_EX}{sep}{Fore.RESET}{text}")

    @staticmethod
    def error(text: str, sep: str = " "):
        timestamp = log._get_timestamp()
        print(f"{timestamp} {Fore.LIGHTRED_EX}ERR {Fore.LIGHTBLACK_EX}{sep}{Fore.RESET}{text}")

    @staticmethod
    def fatal(text: str, sep: str = " "):
        timestamp = log._get_timestamp()
        print(f"{timestamp} {Fore.RED}FTL {Fore.LIGHTBLACK_EX}{sep}{Fore.RESET}{text}")




#! /usr/bin/env python

from setuptools import setup, find_packages

vers = "0.0.0.918"

setup(
    name="terminut",
    version=vers,
    description="Terminut // @imvast",
    long_description_content_type="text/markdown",
    long_description=open("README.md", encoding="utf-8").read(),
    packages=find_packages(exclude=["tests"]),
    author="@imvast",
    url=f"http://pypi.python.org/pypi/terminut",
    author_email="dev@vast.sh",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Visualization",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
    ],
    project_urls={
        "Homepage": "https://github.com/imvast/terminut",
        "Suggestions": "https://github.com/imvast/terminut/issues",
    },
    python_requires="~=3.8",
    install_requires=[
        "colorama>=0.4.6", 
        "requests>=2.30.0"
    ],
)
